==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'affichage_documents_en_cases' => 'Visualizza in box',
	'affichage_documents_en_grand' => 'Visualizza in grande',
	'affichage_documents_en_liste_compacte' => 'Visualizzazione elenco compatto',
	'aucun_audio' => 'Nessun suono',
	'aucun_document' => 'Nessun documento',
	'aucun_file' => 'Nessun documento',
	'aucun_image' => 'Nessuna immagine',
	'aucun_video' => 'Nessun video',
	'aucune_utilisation' => 'Questo documento non è utilizzato',
	'aucune_vignette' => 'Nessuna miniatura',

	// B
	'bouton_ajouter_document' => 'Aggiungi un documento',
	'bouton_ajouter_image' => 'Aggiungi un’immagine',
	'bouton_ajouter_image_document' => 'Aggiungi un’immagine o un documento',
	'bouton_attacher_document' => 'Allega',
	'bouton_copier_local' => 'Copia sul sito',
	'bouton_download_depuis' => 'da:',
	'bouton_download_local' => 'mio computer',
	'bouton_download_par_ftp' => 'il server',
	'bouton_download_par_mediatheque' => 'media library',
	'bouton_download_sur_le_web' => 'internet',
	'bouton_enlever_document' => 'Scollega',
	'bouton_enlever_supprimer_document' => 'Cancella',
	'bouton_enlever_supprimer_document_confirmation' => 'Sei sicuro di voler cancellare il documento?',
	'bouton_modifier_document' => 'Modifica',
	'bouton_parcourir' => 'Sfoglia',
	'bouton_refresh_document' => 'Aggiorna il documento',
	'bouton_remplacer_document' => 'Sostituisci il documento',
	'bouton_remplacer_image' => 'Sostituisci l’immagine',
	'bouton_remplacer_image_document' => 'Sostituisci con un’immagine o un documento',
	'bouton_supprimer' => 'Cancella',
	'bouton_supprimer_tous_orphelins' => 'Elimina tutti i documenti non utilizzati',
	'bouton_supprimer_tous_orphelins_confirmation' => 'Vuoi veramente eliminare @nb@ documenti non utilizzati?',
	'bouton_upload' => 'Carica',

	// D
	'des_audios' => '@nb@ suoni',
	'des_documents' => '@nb@ documenti',
	'des_files' => '@nb@ documenti',
	'des_images' => '@nb@ immagini',
	'des_utilisations' => '@nb@ utilizzazioni',
	'des_videos' => '@nb@ video',
	'descriptif' => 'Descrizione',
	'details_document' => 'Dettagli',
	'details_document_afficher_masquer' => 'Visualizza/nascondi i dettagli del documento',
	'document_attache_succes' => 'Il documento è stato aggiunto con successo',
	'document_copie_locale_succes' => 'Il documento è stato copiato con successo nel sito',
	'document_installe_succes' => 'Il file è stato caricato con successo',
	'document_vu' => 'Inserisci nel testo',
	'documents' => 'Media library',
	'documents_brises' => 'Corrotto',
	'documents_distants' => 'Remoto',
	'documents_locaux' => 'Locale',
	'documents_non_publies' => 'Non pubblicato',
	'documents_orphelins' => 'Non utilizzato',
	'documents_publies' => 'Pubblicato',
	'documents_tous' => 'Tutto',
	'double_clic_inserer_doc' => 'Doppio clic qui per inserire la scorciatoia nel testo',

	// E
	'entree_dimensions' => 'Dimensioni:',
	'entree_titre_document' => 'Titolo del documento:',
	'entree_titre_image' => 'Titolo dell’immagine:',
	'erreur_aucun_document' => 'Il documento non esiste nella media library',
	'erreur_aucun_fichier' => 'Nessun file è stato trovato',
	'erreur_autorisation' => 'Autorizzazione fallita',
	'erreur_chemin_distant' => 'Il file remoto @nom@ non può essere trovato',
	'erreur_chemin_ftp' => 'Il file indicato non è stato trovato nel server',
	'erreur_copie_fichier' => 'Impossibile copiare il file @nom@',
	'erreur_deplacement_impossible' => 'Spostamento impossibile',
	'erreur_dossier_tmp_manquant' => 'La directory temporanea per scaricare il file è mancante',
	'erreur_ecriture_fichier' => 'Errore scrivendo il file sul disco',
	'erreur_format_fichier_image' => 'Il formato di @nom@ non è assimilabile a un’immagine',
	'erreur_indiquez_un_fichier' => 'Specifica un file!',
	'erreur_insertion_document_base' => 'Impossibile salvare il documento @fichier@ nel database',
	'erreur_objet_absent' => 'Informazioni ricevute incomplete',
	'erreur_suppression_vignette' => 'Errore durante la cancellazione della miniatura',
	'erreur_upload_type_interdit' => 'Il caricamento di file del tipo @nom@ non è consentito',
	'erreur_upload_vignette' => 'Errore caricando la miniatura  @nom@',
	'erreurs' => '@nb@ errori',
	'erreurs_voir' => 'Controlla gli @nb@ errori',

	// F
	'fichier_distant' => 'File remoto',
	'fichier_manquant' => 'File mancante',
	'fichier_modifie' => 'Il file è stato modificato. Clicca su pulsante Salva',
	'format_date_incorrect' => 'La data o l’ora sono sbagliate',

	// I
	'icone_creer_document' => 'Aggiungi un documento',
	'id' => 'ID',
	'image_tourner_180' => 'Ruota 180°',
	'image_tourner_droite' => 'Ruota 90° a destra',
	'image_tourner_gauche' => 'Ruota 90° a sinistra',
	'info_alt' => 'Descrizione del contenuto dell’immagine quando non è visibile, oltre al titolo.',
	'info_dimensions_image' => 'Dimensioni',
	'info_doc_max_poids' => 'Il documento deve necessariamente essere più piccolo di @maxi@ (il file è attualmente @actuel@).',
	'info_document' => 'Documento',
	'info_document_indisponible' => 'Questo documento non è disponibile',
	'info_documents' => 'Documenti',
	'info_duree' => 'Durata',
	'info_gauche_numero_document' => 'DOCUMENTO NUMERO',
	'info_hauteur' => 'Altezza',
	'info_heure' => 'Ora',
	'info_illustrations' => 'Illustrazioni',
	'info_image_max_poids' => 'L’immagine deve essere necessariamente grande meno di @maxi@ (il file è @actuel@).',
	'info_image_max_taille' => 'L’immagine deve essere necessariamente grande meno di @maxi@ (il file è @actuel@).',
	'info_image_min_taille' => 'Le immagini devono essere almeno @mini@ (questo file è @actuel@).',
	'info_inclusion_directe' => 'Inclusione diretta:',
	'info_inclusion_vignette' => 'Inclusione dell’immagine:',
	'info_installer_tous_documents' => 'Installare tutti i documenti',
	'info_largeur' => 'Larghezza',
	'info_logo_max_taille' => 'I logo devono obbligatoriamente avere una dimensione inferiore a @maxi@ (questo file è di @actuel@).',
	'info_mode' => 'Modalità',
	'info_modifier_document' => 'Modifica il documento',
	'info_portfolio' => 'Portfolio',
	'info_referencer_doc_distant' => 'Mettere in repertorio un documento su Internet:',
	'info_resolution_image' => 'Risoluzione',
	'info_resolution_mpx' => '@resolution@ Mpx',
	'info_sans_vignette' => 'Nessuna miniatura',
	'info_statut_document' => 'Il documento è:',
	'info_taille' => 'Peso',
	'info_telecharger' => 'Upload dal tuo computer:',
	'info_utilisation' => 'Utilizzo(i)',
	'infos' => 'Informazioni tecniche',
	'inserer_raccourci' => 'Inserisci questa scorciatoia nel testo',
	'item_autoriser_selectionner_date_en_ligne' => 'Permetti di modificare la data di ogni documento',
	'item_non_autoriser_selectionner_date_en_ligne' => 'La data dei documenti è quella in cui sono stati aggiunti al sito.',

	// L
	'label_activer_document_objets' => 'Attiva il caricamento di documento per il contenuto:',
	'label_alt' => 'Testo alternativo (alt)',
	'label_apercu' => 'Anteprima',
	'label_caracteristiques' => 'Specifiche',
	'label_credits' => 'Crediti',
	'label_fichier' => 'File',
	'label_fichier_vignette' => 'Miniature',
	'label_paginer_par' => 'Impaginare da :',
	'label_parents' => 'Il documento è collegato a',
	'label_refdoc_joindre' => 'Documento numero',
	'label_titre_mimetype' => 'Tipo di file',
	'lien_tout_desordonner' => 'Ripristina l’ordine',
	'lien_tout_desordonner_verif' => 'L’ordine definito per questo elenco di documenti verrà reimpostato. Sei sicuro?',
	'lien_tout_enlever' => 'Rimuovi tutto',
	'lien_tout_enlever_verif' => 'Vuoi staccare tutti i documenti?',
	'logo' => 'Logo',

	// M
	'media_audio' => 'Suono',
	'media_file' => 'Altro',
	'media_image' => 'Immagini',
	'media_video' => 'Video',
	'miniature_automatique_active' => 'SPIP genererà automaticamente le miniature dell’immagine',

	// N
	'nb_documents_attache_succes' => '@nb@ documenti sono stati aggiunti',
	'nb_documents_installe_succes' => '@nb@ file sono stati caricati con successo',

	// O
	'objet_document' => 'Documento',
	'objet_documents' => 'Documenti',
	'ordonner_ce_document' => 'Ordina questo documento',

	// P
	'par_date' => 'Data',
	'par_hauteur' => 'Altezza',
	'par_id' => 'ID',
	'par_largeur' => 'Larghezza',
	'par_taille' => 'Peso',
	'par_titre' => 'Titolo',

	// T
	'texte_documents_joints' => 'Puoi abilitare l’interfaccia per l’aggiunta di documenti (file di testo, fogli elettronici, immagini, file multimediali, ecc.) agli articoli, rubriche e altro. Questi file possono poi essere richiamati nel testo dell’articolo, o visualizzati separatamente.',
	'texte_documents_joints_2' => 'Questa impostazione non impedisce il caricamento diretto di immagini nell’articolo ne l’inclusione di documenti nel testo del contenuto.',
	'titre_documents_joints' => 'Documenti allegati',
	'titre_page_documents_edit' => 'Modifica il documento: @titre@',
	'tous_les_medias' => 'Tutti i media',
	'tout_dossier_upload' => 'Tutta la cartella @upload@',
	'tout_voir' => 'Mostra tutto',

	// U
	'un_audio' => '1 suono',
	'un_document' => '1 documento',
	'un_file' => '1 documento',
	'un_image' => '1 immagine',
	'un_video' => '1 video',
	'une_utilisation' => '1 utilizzazione',
	'upload_fichier_zip' => 'File ZIP',
	'upload_fichier_zip_texte' => 'Il file proposto è un file ZIP.',
	'upload_fichier_zip_texte2' => 'Questo file può essere:',
	'upload_info_mode_document' => 'Invia al portfolio',
	'upload_info_mode_image' => 'Rimuovi dal portfolio',
	'upload_limit' => 'Questo file è troppo grande per il server; la dimensione massima consentita per gli <i>upload</i> è di @max@.',
	'upload_zip_conserver' => 'Conserva il file archivio dopo l’estrazione del contenuto',
	'upload_zip_decompacter' => 'decompresso e ogni elemento installato nel sito. I file che saranno installati nel sito sono:',
	'upload_zip_mode_document' => 'Inserisci tutte le immagini nel portfolio',
	'upload_zip_telquel' => 'installato così com’è in quanto archivio compresso Zip;',
	'upload_zip_titrer' => 'Dare i titoli in base al nome dei file',

	// V
	'verifier_documents_brises' => 'Controlla i file mancanti',
	'verifier_documents_inutilises' => 'Controlla i link ai documenti',
	'vignette_supprimee' => 'La miniatura è stata cancellata'
);

==> spip_4.4.9+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=it
// ** ne pas modifier le fichier **

return [

	// A
	'affichage_documents_en_cases' => 'Visualizza in box',
	'affichage_documents_en_grand' => 'Visualizza in grande',
	'affichage_documents_en_liste_compacte' => 'Visualizzazione elenco compatto',
	'aucun_audio' => 'Nessun suono',
	'aucun_document' => 'Nessun documento',
	'aucun_file' => 'Nessun documento',
	'aucun_image' => 'Nessuna immagine',
	'aucun_video' => 'Nessun video',
	'aucune_utilisation' => 'Questo documento non è utilizzato',
	'aucune_vignette' => 'Nessuna miniatura',

	// B
	'bouton_ajouter_document' => 'Aggiungi un documento',
	'bouton_ajouter_image' => 'Aggiungi un’immagine',
	'bouton_ajouter_image_document' => 'Aggiungi un’immagine o un documento',
	'bouton_attacher_document' => 'Allega',
	'bouton_copier_local' => 'Copia sul sito',
	'bouton_download_depuis' => 'da:',
	'bouton_download_local' => 'mio computer',
	'bouton_download_par_ftp' => 'il server',
	'bouton_download_par_mediatheque' => 'media library',
	'bouton_download_sur_le_web' => 'internet',
	'bouton_enlever_document' => 'Scollega',
	'bouton_enlever_supprimer_document' => 'Cancella',
	'bouton_enlever_supprimer_document_confirmation' => 'Sei sicuro di voler cancellare il documento?',
	'bouton_modifier_document' => 'Modifica',
	'bouton_parcourir' => 'Sfoglia',
	'bouton_refresh_document' => 'Aggiorna il documento',
	'bouton_remplacer_document' => 'Sostituisci il documento',
	'bouton_remplacer_image' => 'Sostituisci l’immagine',
	'bouton_remplacer_image_document' => 'Sostituisci con un’immagine o un documento',
	'bouton_supprimer' => 'Cancella',
	'bouton_supprimer_tous_orphelins' => 'Elimina tutti i documenti non utilizzati',
	'bouton_supprimer_tous_orphelins_confirmation' => 'Vuoi veramente eliminare @nb@ documenti non utilizzati?',
	'bouton_upload' => 'Carica',

	// D
	'des_audios' => '@nb@ suoni',
	'des_documents' => '@nb@ documenti',
	'des_files' => '@nb@ documenti',
	'des_images' => '@nb@ immagini',
	'des_utilisations' => '@nb@ utilizzazioni',
	'des_videos' => '@nb@ video',
	'descriptif' => 'Descrizione', # MODIF
	'details_document' => 'Dettagli',
	'details_document_afficher_masquer' => 'Visualizza/nascondi i dettagli del documento',
	'document_attache_succes' => 'Il documento è stato aggiunto con successo',
	'document_copie_locale_succes' => 'Il documento è stato copiato con successo nel sito',
	'document_installe_succes' => 'Il file è stato caricato con successo',
	'document_vu' => 'Inserisci nel testo',
	'documents' => 'Media library',
	'documents_brises' => 'Corrotto',
	'documents_distants' => 'Remoto',
	'documents_locaux' => 'Locale',
	'documents_non_publies' => 'Non pubblicato',
	'documents_orphelins' => 'Non utilizzato',
	'documents_publies' => 'Pubblicato',
	'documents_tous' => 'Tutto',
	'double_clic_inserer_doc' => 'Doppio clic qui per inserire la scorciatoia nel testo',

	// E
	'entree_dimensions' => 'Dimensioni:',
	'entree_titre_document' => 'Titolo del documento:',
	'entree_titre_image' => 'Titolo dell’immagine:',
	'erreur_aucun_document' => 'Il documento non esiste nella media library',
	'erreur_aucun_fichier' => 'Nessun file è stato trovato',
	'erreur_autorisation' => 'Autorizzazione fallita',
	'erreur_chemin_distant' => 'Il file remoto @nom@ non può essere trovato',
	'erreur_chemin_ftp' => 'Il file indicato non è stato trovato nel server',
	'erreur_copie_fichier' => 'Impossibile copiare il file @nom@',
	'erreur_deplacement_impossible' => 'Spostamento impossibile',
	'erreur_dossier_tmp_manquant' => 'La directory temporanea per scaricare il file è mancante',
	'erreur_ecriture_fichier' => 'Errore scrivendo il file sul disco',
	'erreur_format_fichier_image' => 'Il formato di @nom@ non è assimilabile a un’immagine',
	'erreur_indiquez_un_fichier' => 'Specifica un file!',
	'erreur_insertion_document_base' => 'Impossibile salvare il documento @fichier@ nel database',
	'erreur_objet_absent' => 'Informazioni ricevute incomplete',
	'erreur_suppression_vignette' => 'Errore durante la cancellazione della miniatura',
	'erreur_upload_type_interdit' => 'Il caricamento di file del tipo @nom@ non è consentito',
	'erreur_upload_vignette' => 'Errore caricando la miniatura  @nom@',
	'erreurs' => '@nb@ errori',
	'erreurs_voir' => 'Controlla gli @nb@ errori',

	// F
	'fichier_distant' => 'File remoto',
	'fichier_manquant' => 'File mancante',
	'fichier_modifie' => 'Il file è stato modificato. Clicca su pulsante Salva',
	'format_date_incorrect' => 'La data o l’ora sono sbagliate',

	// I
	'icone_creer_document' => 'Aggiungi un documento',
	'id' => 'ID',
	'image_tourner_180' => 'Ruota 180°',
	'image_tourner_droite' => 'Ruota 90° a destra',
	'image_tourner_gauche' => 'Ruota 90° a sinistra',
	'info_alt' => 'Descrizione del contenuto dell’immagine quando non è visibile, oltre al titolo.',
	'info_dimensions_image' => 'Dimensioni',
	'info_doc_max_poids' => 'Il documento deve necessariamente essere più piccolo di @maxi@ (il file è attualmente @actuel@).',
	'info_document' => 'Documento',
	'info_document_indisponible' => 'Questo documento non è disponibile',
	'info_documents' => 'Documenti',
	'info_duree' => 'Durata',
	'info_gauche_numero_document' => 'DOCUMENTO NUMERO',
	'info_hauteur' => 'Altezza',
	'info_heure' => 'Ora',
	'info_illustrations' => 'Illustrazioni',
	'info_image_max_poids' => 'L’immagine deve essere necessariamente grande meno di @maxi@ (il file è @actuel@).',
	'info_image_max_taille' => 'L’immagine deve essere necessariamente grande meno di @maxi@ (il file è @actuel@).',
	'info_image_min_taille' => 'Le immagini devono essere almeno @mini@ (questo file è @actuel@).',
	'info_inclusion_directe' => 'Inclusione diretta:',
	'info_inclusion_vignette' => 'Inclusione dell’immagine:',
	'info_installer_tous_documents' => 'Installare tutti i documenti',
	'info_largeur' => 'Larghezza',
	'info_logo_max_taille' => 'I logo devono obbligatoriamente avere una dimensione inferiore a @maxi@ (questo file è di @actuel@).',
	'info_mode' => 'Modalità',
	'info_modifier_document' => 'Modifica il documento',
	'info_portfolio' => 'Portfolio',
	'info_referencer_doc_distant' => 'Mettere in repertorio un documento su Internet:',
	'info_resolution_image' => 'Risoluzione',
	'info_resolution_mpx' => '@resolution@ Mpx',
	'info_sans_vignette' => 'Nessuna miniatura',
	'info_statut_document' => 'Il documento è:',
	'info_taille' => 'Peso',
	'info_telecharger' => 'Upload dal tuo computer:',
	'info_utilisation' => 'Utilizzo(i)',
	'infos' => 'Informazioni tecniche',
	'inserer_raccourci' => 'Inserisci questa scorciatoia nel testo',
	'item_autoriser_selectionner_date_en_ligne' => 'Permetti di modificare la data di ogni documento',
	'item_non_autoriser_selectionner_date_en_ligne' => 'La data dei documenti è quella in cui sono stati aggiunti al sito.',

	// L
	'label_activer_document_objets' => 'Attiva il caricamento di documento per il contenuto:',
	'label_alt' => 'Testo alternativo (alt)',
	'label_apercu' => 'Anteprima',
	'label_caracteristiques' => 'Specifiche',
	'label_credits' => 'Crediti',
	'label_fichier' => 'File',
	'label_fichier_vignette' => 'Miniature',
	'label_paginer_par' => 'Impaginare da :',
	'label_parents' => 'Il documento è collegato a',
	'label_refdoc_joindre' => 'Documento numero',
	'label_titre_mimetype' => 'Tipo di file',
	'lien_tout_desordonner' => 'Ripristina l’ordine',
	'lien_tout_desordonner_verif' => 'L’ordine definito per questo elenco di documenti verrà reimpostato. Sei sicuro?',
	'lien_tout_enlever' => 'Rimuovi tutto',
	'lien_tout_enlever_verif' => 'Vuoi staccare tutti i documenti?',
	'logo' => 'Logo',

	// M
	'media_audio' => 'Suono',
	'media_file' => 'Altro',
	'media_image' => 'Immagini',
	'media_video' => 'Video',
	'miniature_automatique_active' => 'SPIP genererà automaticamente le miniature dell’immagine',

	// N
	'nb_documents_attache_succes' => '@nb@ documenti sono stati aggiunti',
	'nb_documents_installe_succes' => '@nb@ file sono stati caricati con successo',

	// O
	'objet_document' => 'Documento',
	'objet_documents' => 'Documenti',
	'ordonner_ce_document' => 'Ordina questo documento',

	// P
	'par_date' => 'Data',
	'par_hauteur' => 'Altezza',
	'par_id' => 'ID',
	'par_largeur' => 'Larghezza',
	'par_taille' => 'Peso',
	'par_titre' => 'Titolo',

	// T
	'texte_documents_joints' => 'Puoi abilitare l’interfaccia per l’aggiunta di documenti (file di testo, fogli elettronici, immagini, file multimediali, ecc.) agli articoli, rubriche e altro. Questi file possono poi essere richiamati nel testo dell’articolo, o visualizzati separatamente.',
	'texte_documents_joints_2' => 'Questa impostazione non impedisce il caricamento diretto di immagini nell’articolo ne l’inclusione di documenti nel testo del contenuto.',
	'titre_documents_joints' => 'Documenti allegati',
	'titre_page_documents_edit' => 'Modifica il documento: @titre@',
	'tous_les_medias' => 'Tutti i media',
	'tout_dossier_upload' => 'Tutta la cartella @upload@',
	'tout_voir' => 'Mostra tutto',

	// U
	'un_audio' => '1 suono',
	'un_document' => '1 documento',
	'un_file' => '1 documento',
	'un_image' => '1 immagine',
	'un_video' => '1 video',
	'une_utilisation' => '1 utilizzazione',
	'upload_fichier_zip' => 'File ZIP',
	'upload_fichier_zip_texte' => 'Il file proposto è un file ZIP.',
	'upload_fichier_zip_texte2' => 'Questo file può essere:',
	'upload_info_mode_document' => 'Invia al portfolio',
	'upload_info_mode_image' => 'Rimuovi dal portfolio',
	'upload_limit' => 'Questo file è troppo grande per il server; la dimensione massima consentita per gli <i>upload</i> è di @max@.',
	'upload_zip_conserver' => 'Conserva il file archivio dopo l’estrazione del contenuto',
	'upload_zip_decompacter' => 'decompresso e ogni elemento installato nel sito. I file che saranno installati nel sito sono:',
	'upload_zip_mode_document' => 'Inserisci tutte le immagini nel portfolio',
	'upload_zip_telquel' => 'installato così com’è in quanto archivio compresso Zip;',
	'upload_zip_titrer' => 'Dare i titoli in base al nome dei file',

	// V
	'verifier_documents_brises' => 'Controlla i file mancanti',
	'verifier_documents_inutilises' => 'Controlla i link ai documenti',
	'vignette_supprimee' => 'La miniatura è stata cancellata',
];
